from rest_framework import serializers
from arkindex.dataimport.models import Worker, WorkerVersion, WorkerVersionState
from arkindex.project.serializer_fields import EnumField
from arkindex_common.ml_tool import MLToolType
from arkindex.dataimport.serializers.git import RevisionWithRefsSerializer


class WorkerSerializer(serializers.ModelSerializer):
    """
    Serialize a repository worker
    """
    type = EnumField(MLToolType)

    class Meta:
        model = Worker
        fields = (
            'id',
            'name',
            'slug',
            'type',
        )


class WorkerVersionSerializer(serializers.ModelSerializer):
    """
    Serialize a worker version
    """
    state = EnumField(WorkerVersionState, required=False)
    worker = WorkerSerializer(read_only=True)
    # ModelSerializer does not yet support Django 3.1's JSONField
    # https://github.com/encode/django-rest-framework/pull/7467
    configuration = serializers.JSONField()

    class Meta:
        model = WorkerVersion
        fields = (
            'id',
            'configuration',
            'revision',
            'docker_image',
            'docker_image_name',
            'state',
            'worker',
        )
        read_only_fields = ('docker_image_name',)

    def to_representation(self, instance):
        self.fields['revision'] = RevisionWithRefsSerializer(read_only=True)
        return super(WorkerVersionSerializer, self).to_representation(instance)
