from django.conf import settings
from django.db import models
from django.utils.functional import cached_property


class ImageServerManager(models.Manager):

    @cached_property
    def local(self):
        return self.get(id=settings.LOCAL_IMAGESERVER_ID)

    def from_url(self, url):
        """
        Find a matching ImageServer from an image URL. Requires the server to be validated.
        May raise ImageServer.DoesNotExist or ImageServer.MultipleObjectsReturned.
        """
        servers = self \
            .annotate(image_url=models.Value(url, output_field=models.CharField())) \
            .filter(validated=True, image_url__startswith=models.F('url'))

        servers_count = servers.count()
        if not servers_count:
            raise self.model.DoesNotExist(
                'This resource does not match any existing image server'
            )
        elif servers_count > 1:
            raise self.model.MultipleObjectsReturned(
                'This resource matched multiple existing image servers'
            )

        return servers.get()
