from django.views.generic import View, TemplateView
from django.conf import settings
from arkindex.project.mixins import CachedViewMixin


class FrontendView(View):
    """
    View that show the frontend's router
    TODO: Get rid of this view once the frontend is fully split
    """


class CdnHome(CachedViewMixin, TemplateView):
    """
    Index template to use frontend assets from a CDN
    """
    template_name = 'index.html'
    cache_timeout = 86400
    cache_prefix = settings.FRONTEND_VERSION

    def get_context_data(self, *args, **kwargs):
        ctx = super().get_context_data(*args, **kwargs)
        ctx['cdn_assets_url'] = settings.CDN_ASSETS_URL
        ctx['mirador_url'] = settings.MIRADOR_URL
        ctx['universal_viewer_url'] = settings.UNIVERSAL_VIEWER_URL
        ctx['version'] = settings.VERSION
        ctx['frontend_version'] = settings.FRONTEND_VERSION
        ctx['frontend_sentry_dsn'] = settings.FRONTEND_SENTRY_DSN
        return ctx


class OpenAPIDocsView(CachedViewMixin, TemplateView):
    """
    OpenAPI documentation via ReDoc
    """
    template_name = 'redoc.html'
    cache_timeout = 86400
    cache_prefix = settings.VERSION
